==> com.liferay.layout.content.page.editor.web-1.0.20.jar: META-INF/resources/js/components/sidebar/mapping/SidebarMappingPanel.es.js <==
"use strict";

Liferay.Loader.define("layout-content-page-editor-web@1.0.20/js/components/sidebar/mapping/SidebarMappingPanel.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', '../../mapping_type/SelectMappingTypeForm.es', './SidebarMappingPanel.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = exports.SidebarMappingPanel = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  require("../../mapping_type/SelectMappingTypeForm.es");

  var _SidebarMappingPanel = _interopRequireDefault(require("./SidebarMappingPanel.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * SidebarMappingPanel
   */
  var SidebarMappingPanel =
  /*#__PURE__*/
  function (_Component) {
    _inherits(SidebarMappingPanel, _Component);

    function SidebarMappingPanel() {
      _classCallCheck(this, SidebarMappingPanel);

      return _possibleConstructorReturn(this, _getPrototypeOf(SidebarMappingPanel).apply(this, arguments));
    }

    return SidebarMappingPanel;
  }(_metalComponent.default);

  exports.SidebarMappingPanel = SidebarMappingPanel;

  _metalSoy.default.register(SidebarMappingPanel, _SidebarMappingPanel.default);

  var _default = SidebarMappingPanel;
  exports.default = _default;
  //# sourceMappingURL=SidebarMappingPanel.es.js.map
});
//# sourceMappingURL=SidebarMappingPanel.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/sidebar/mapping/SidebarMappingPanel.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/sidebar/mapping/SidebarMappingPanel.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', '../../../store/ConnectedComponent.es', './SidebarMappingPanel.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.SidebarMappingPanel = exports.ConnectedSidebarMappingPanel = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _ConnectedComponent = _interopRequireDefault(require("../../../store/ConnectedComponent.es"));

  var _SidebarMappingPanel = _interopRequireDefault(require("./SidebarMappingPanel.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * SidebarMappingPanel
   */
  var SidebarMappingPanel =
  /*#__PURE__*/
  function (_Component) {
    _inherits(SidebarMappingPanel, _Component);

    function SidebarMappingPanel() {
      _classCallCheck(this, SidebarMappingPanel);

      return _possibleConstructorReturn(this, _getPrototypeOf(SidebarMappingPanel).apply(this, arguments));
    }

    return SidebarMappingPanel;
  }(_metalComponent["default"]);

  exports.SidebarMappingPanel = SidebarMappingPanel;
  var ConnectedSidebarMappingPanel = (0, _ConnectedComponent["default"])(SidebarMappingPanel, ['selectedMappingTypes']);
  exports.ConnectedSidebarMappingPanel = ConnectedSidebarMappingPanel;

  _metalSoy["default"].register(ConnectedSidebarMappingPanel, _SidebarMappingPanel["default"]);

  var _default = ConnectedSidebarMappingPanel;
  exports["default"] = _default;
  //# sourceMappingURL=SidebarMappingPanel.es.js.map
});
//# sourceMappingURL=SidebarMappingPanel.es.js.map
